var simpleCartInstance = [];
var eCommerceVersion = 1.10;

/**
 * SIMPLE CART EXTENTION
 * Add new function to simple cart to handle discount with our vision and
 * enable or disable discount mode and then update the simple cart.
 * @param String action "on"|"off"
 */
simpleCart.discountMode = function (action, discountValue) {
	action = typeof action !== 'undefined' ? action : "off";
	discountValue = typeof discountValue !== 'undefined' ? discountValue : 0;
	if (action == "off") {
		discountValue = 0;
	}

	simpleCart.total = function () {
		var total = 0;
		simpleCart.each(function (item) {
			total += item.total();
		});
		return (Math.max(0, total - discountValue));
	};
	simpleCart.update();
}

/**
 * Add required filters used in the invoice modal service.
 */
angular.module('ngApp')
.filter('toCurrency', function() {
	return function (value) {
			return simpleCart.toCurrency(value);
	}
})
.filter('toStatus', function() {
	return function (value) {
			switch (value) {
				case 0:
				 return "در انتظار بررسی";
				case "1":
				 return "در انتظار پرداخت";
				case "2":
				 return "در حال انجام";
				case "3":
				 return "ارسال شده";
				case "4":
				 return "دریافت توسط مشتری";
				default:
				 return "ناشناس";
			}
	}
});

angular.module('ngApp').controller('eCommerceCtrl', function ($scope, $ionicModal, $http, $ionicScrollDelegate, checkoutService, $ionicPopup, $sce, $rootScope, invoiceService, checkoutService, $state) {
	$rootScope.invoiceService = invoiceService;
	$rootScope.checkoutService = checkoutService;
	$rootScope.eCommerceVersion = eCommerceVersion;
	$scope.products = [];
	$scope.storage = '';
	$scope.noMoreItemsAvailable = true;
	$scope.slideIndex = 0;
	$scope.landing = [];

	setTimeout(function() {
		updateSimpleCartInstances();
	}, 1000);

	$scope.checkoutService = checkoutService;
	// Wait until the sl var is init
	$scope.$watch('sl', function () {
		$scope.showProducts(false);
	});

	$scope.showProducts = function(refresh) {
		// Load news
	  if(isOnline()){
		if(!refresh){
		  $scope.loading = true;
		}
		$http({method: 'GET', noLoading : true, url: url + '/api/v1/widget/route/e-commerce/getProduct/' + $scope.sl})
		.success(function(data) {
			if(data.products)
			{
				$scope.products = data.products;
				if(data.products.length == 6){
					$scope.noMoreItemsAvailable = false;
				}
				$scope.storage = '';
				if(data.landing){
					$scope.landing = data.landing;
					var loop = $scope.landing.slider.effect == 'cube' ? false : true;
					$scope.slideroptions = {
						preventClicks: false,
						preventClicksPropagation: false,
						autoplayDisableOnInteraction: false,
						loop: loop,
						speed: 400,
						//autoHeight: true,
						autoplay: $scope.landing.slider.duration * 1000,
						effect: $scope.landing.slider.effect
					};

					setTimeout(function () {
						$ionicScrollDelegate.scrollTo(2000,0,false);
					}, 100);
				}
				else{
					$scope.storage = data.error;
				}
			}else{
				$scope.storage = lang('e-commerce.fail_to_load_items');
			}
			$scope.loading = false;
			$scope.$broadcast('scroll.refreshComplete');
		})
		.error(function() {
			$scope.storage = lang('e-commerce.fail_to_load_items');
			$scope.loading = false;
			$scope.$broadcast('scroll.refreshComplete');
		});
	  }else{
		$scope.loading = false;
		checkYourInternet();
	  }
	};


	$scope.doRefresh = function() {
		$scope.showProducts(true);
		//$scope.noMoreItemsAvailable = false;
	};

	$scope.loadMore = function() {
		if(!$scope.noMoreItemsAvailable){
			$scope.noMoreItemsAvailable = true;
			var start = $scope.products.length;
			if(isOnline()){
				$scope.infiniteScrollLoading = true;
				$http({method: 'GET', noLoading : true, url: url + '/api/v1/widget/route/e-commerce/getProduct/' + $scope.sl + '/' + start})
				.success(function(data) {
					if (data.products.length == 0)
					{
						$scope.noMoreItemsAvailable = true;
					}
					else
					{
						for (var i = 0 ; i < data.products.length ; i++)
						{
							$scope.products.push(data.products[i]);
						}
					}
					if(data.products.length < 6){
						$scope.noMoreItemsAvailable = true;
					}else{
						$scope.noMoreItemsAvailable = false;
					}
					$scope.infiniteScrollLoading = false;
					$scope.$broadcast('scroll.infiniteScrollComplete');
				})
				.error(function() {
					console.error('ERR', err.status);
					$scope.infiniteScrollLoading = false;
					$scope.$broadcast('scroll.infiniteScrollComplete');
				});
			}
		}
	};

	$scope.showConfirm = function() {
		$ionicPopup.confirm({
			title: '',
			template: lang('e-commerce.item_added_to_cart'),
			okText: lang('e-commerce.pay'),
			okType: 'button-success',
			cancelText: lang('e-commerce.continues'),
			cancelType: 'button-info',
		}).then(function(res) {
			if (res) {
				checkoutService.showModal()
			} else {
				updateSimpleCartInstances();
			}
		});
	};

	$scope.slideroptions = {
		preventClicks: false,
		preventClicksPropagation: false,
		autoplayDisableOnInteraction: false,
		loop: false,
		speed: 400,
		//autoHeight: true,
		autoplay: 7000,
		autoplayStopOnLast : true
	};

	$ionicModal.fromTemplateUrl('product-modal.html', {
		scope: $scope,
		animation: 'slide-in-up',
		hardwareBackButtonClose: true
	}).then(function(modal) {
		$scope.modal = modal;
	});

	$scope.openModal = function(index) {
		$scope.product = $scope.products[index];
		$scope.fetureImage = ($scope.products[index].image != '') ? true : false;
		var isWebView = ionic.Platform.isWebView();
		var isStandalone = ionic.Platform.isAndroid() ? window.matchMedia('(display-mode: standalone)').matches : window.navigator.standalone === true;
		if(!isStandalone && !isWebView) {
			$('.swiper-pagination').show();
			if($scope.product.images.length <= 1)
				setTimeout(function() {$('.swiper-pagination').hide()}, 200);
			$scope.content = $sce.trustAsHtml($scope.product.description);
			$scope.hasTabs = false;
			if(typeof $scope.product.tabs != 'undefined' && $scope.product.tabs != null) {
				for (var i = 0; i < $scope.product.tabs.length; i++) {
					if(typeof $scope.product.tabs[i].body == 'string') {
						$scope.product.tabs[i].body = $sce.trustAsHtml($scope.product.tabs[i].body);
					}
					$scope.hasTabs = true;
				}
			}
			$scope.showOptions = false;
			$scope.inZoom = false;
			$scope.modal.show();
			$rootScope.openModal = $scope.modal;
			$scope.options = $scope.product.options || [];
			$scope.optionskey = Object.keys($scope.options);
		} else {
			$state.go('nav.widget1', {
    			widget: 'e-commerce',
    			func: 'getSingle',
            	sl: $scope.sl,
            	id: $scope.product.id
			});
		}
	};

	$scope.closeModal = function() {
		$scope.modal.hide();
		$scope.content = '';
		$scope.optionskey = $scope.options = $scope.product = [];
		$scope.showOptions = $scope.inZoom = false;
		updateSimpleCartInstances();
	};

	$scope.$on('modal.shown', function() {
		$ionicScrollDelegate.$getByHandle('modal').scrollTop();
	});

	$scope.zoom = function(){
		if($scope.inZoom){
			$ionicScrollDelegate.$getByHandle('inner'+$scope.slideIndex).zoomTo(1,true);
			$scope.inZoom = false;
		}else{
			$ionicScrollDelegate.$getByHandle('inner'+$scope.slideIndex).zoomTo(2,true);
			$scope.inZoom = true;
		}
	}
	// Called each time the slide changes
	$scope.$on("$ionicSlides.slideChangeEnd", function(event, data){
		if($scope.inZoom = true){
			$ionicScrollDelegate.$getByHandle('inner' + $scope.slideIndex).zoomTo(1,true);
			$scope.inZoom = false;
		}
		$scope.slideIndex = data.slider.activeIndex;
	});
	
	// open options modal
	$scope.showOptionsModal = function() {
		if(typeof($scope.product.options) != 'undefined' && !angular.equals($scope.product.options, {}) && !angular.equals($scope.product.options, [])){
			$scope.showOptions = true;
			$scope.orginalPrice = $scope.product.price;
		}else{
			simpleCart.add({
				id: $scope.product.code ,
				name: $scope.product.title ,
				price: $scope.product.price ,
				thumb: $scope.product.thumb ,
				nstock: $scope.product.nstock ,
				quantity: 1
			});
			$scope.addToCart();
		}
	};

	// close options modal
	$scope.hideOptionsModal = function () {
		$scope.showOptions = false;
	};
	
	$scope.addToCart = function() {
		$scope.showOptions = false;
		if(eCommerceOpenCart){
			checkoutService.showModal();
		}else{
			showSuccess(lang('e-commerce.item_added_to_cart'), 1500);
		}
	};

	$scope.changeOption = function(key,value) {
		if(typeof($scope.product.optionsPrice) != 'undefined' && key == $scope.product.optionsPrice.key){
			$scope.product.price = $scope.product.optionsPrice.price[value] || $scope.orginalPrice;
		}
	};

})
.filter('dashless',function() {
	return function(input) {
		if (input) {
			return input.replace(/-/g, ' ');
		}
	}
})
.filter('farsinum', function () {
	return function (input) {
		if (input == 0) {
			return lang('e-commerce.free');
		}
		if (input && lang('global.locale') == 'fa') {
			input = input.replace(/0/g, '۰').replace(/1/g, '۱').replace(/2/g, '۲').replace(/3/g, '۳').replace(/4/g, '۴').replace(/5/g, '۵').replace(/6/g, '۶').replace(/7/g, '۷').replace(/8/g, '۸').replace(/9/g, '۹');
			return input + ' ' + lang('global.toman');
		}
		return input;
	}
})
.controller('TabController', ['$scope', function($scope) {
    $scope.tab = 1;

    $scope.setTab = function(newTab){
      $scope.tab = newTab;
    };

    $scope.isSet = function(tabNum){
      return $scope.tab === tabNum;
    };
}]);

angular.module('ngApp').service('invoiceService', function($ionicModal, localStorage, $http) {
	/**
	 * Show modal
	 */
	this.showModal = function() {
		var service = this;

		$ionicModal.fromTemplateUrl('invoice.html', {
			scope: null,
			animation: 'slide-in-up',
			hardwareBackButtonClose: true
		}).then(function(modal) {
			service.modal = modal;
			service.modal.show();

			service.modal.saveInvoicesIntoTheLS = function (invoices, haveResult) {
				var arrayToSaveInLS = {};
				if (haveResult) {
					arLength = invoices.length;
				}
				angular.forEach(invoices, function(value, key) {
					if (value.code) {
						arrayToSaveInLS[value.code] = value;
					}
					if (arLength-- == 1) {
						localStorage.save(arrayToSaveInLS, 'einvoices' + EcmmerceHash);
					}
				});
			}

			service.modal.showSingleInvoice = function (code) {
					$ionicModal.fromTemplateUrl('single-invoice.html', {
						scope: null,
						animation: 'slide-in-up',
						hardwareBackButtonClose: true
					}).then(function(modal) {
						service.modal.singleInvoiceModal = modal;
						service.modal.singleInvoiceModal.show();
						service.modal.singleInvoiceModal.invoice = localStorage.get('einvoices' + EcmmerceHash, code);
						service.modal.singleInvoiceModal.getVariations = function (item) {
							var temp = { 
								options: function () {
									return item.options;
								} 
							};
							return simpleCart.getVariations(temp);
						}
					});
			}

			service.modal.search = function () {
				var searchData = {};
				if (modal.searchText) {
					searchData = { "needle": modal.searchText, "orderIds": "" }
				} else {
					searchData = {
						"needle": "",
						"orderIds": localStorage.all('eorderids' + EcmmerceHash)
					}
				}

				$http({
					method: 'POST',
					url: url + '/api/v1/widget/post/e-commerce/postSearchInvoices?sl=' + $app_sl,
					data: searchData
				})
				.success(function (data) {
					service.modal.invoices = data.invoices;
					service.modal.haveResult = data.have_result;
					service.modal.saveInvoicesIntoTheLS(data.invoices, data.have_result);
				})
				.error(function () {
					checkYourInternet();
				});
			}

			$http({
				method: 'POST',
				url: url + '/api/v1/widget/post/e-commerce/postSearchInvoices?sl=' + $app_sl,
				data: {
					"needle": "",
					"orderIds": localStorage.all('eorderids' + EcmmerceHash)
				}
			})
			.success(function (data) {
				service.modal.invoices = data.invoices;
				service.modal.haveResult = data.have_result;
				service.modal.saveInvoicesIntoTheLS(data.invoices, data.have_result);
			})
			.error(function () {
				checkYourInternet();
			});
		});
	};

	this.hideModal = function() {
		this.modal.hide();
	};

	this.checkout = function(modal) {
		localStorage.save(modal.user,'euser');
		simpleCart.checkout();
	};

});
var service;
angular.module('ngApp').service('checkoutService', function ($ionicModal, localStorage, ionicDatePicker, ionicTimePicker) {

	this.showModal = function() {

		service = this;

		$ionicModal.fromTemplateUrl('checkout.html', {
			scope: null,
			animation: 'slide-in-up',
			hardwareBackButtonClose: true
		}).then(function(modal) {
			service.modal = modal;
			service.modal.show();
			service.modal.checkout = service.checkout;
			service.modal.openDatePicker = service.openDatePicker;
			service.modal.forms = [];
			service.modal.user = localStorage.all('euser');
			updateSimpleCartInstances();
		});
	};

	this.hideModal = function() {
		this.modal.hide();
		updateSimpleCartInstances();
	};

	this.checkout = function(modal) {
		localStorage.save(modal.user,'euser');
		simpleCart.checkout();
	};

	var datevalue = false,
		timevalue = false;
	this.openDatePicker = function (index, time) {
		setTimeout(function(){
			ionicDatePicker.openDatePicker({
				callback: function (unix, dateString) {
					datevalue = unix;
					service.modal.forms[index] = dateString;
					if (time) {
						ionicTimePicker.openTimePicker({
							callback: function (val) {
								timevalue = val;
								var selectedTime = typeof (val) === 'undefined' ? new Date() : new Date(val * 1000);
								service.modal.forms[index] = dateString + ' - ' + selectedTime.getUTCHours() + ':' + selectedTime.getUTCMinutes();
							},
							inputTime: timevalue != false ? timevalue : (new Date()).getHours() * 60 * 60,
						});
					}
				},
				inputDate: datevalue != false ? new Date(datevalue) : new Date(),
			});
		}, 200);
	};

	this.openTimePicker = function (index) {
		setTimeout(function () {
			ionicTimePicker.openTimePicker({
				callback: function (val) {
					timevalue = val;
					var selectedTime = typeof (val) === 'undefined' ? new Date() : new Date(val * 1000);
					service.modal.forms[index] = selectedTime.getUTCHours() + ':' + selectedTime.getUTCMinutes();
				},
				inputTime: timevalue != false ? timevalue : (new Date()).getHours() * 60 * 60,
			});
		},200);
	};

});

function updateSimpleCartInstances()
{
	// Default grant total value to clear price with discount of previous state.
	simpleCart.discountMode("off");

	if(simpleCart.quantity() == 0){
		$('.cartCount').hide();
	} else {
		$('.cartCount').show(100);
	}
	$('.taxRate').text(simpleCart.taxRate() * 100);

	$('.item_price, .shop_price, .itemRow .item-price, .itemRow .item-total').each(function(index, element) {
		var price = parseFloat($(this).text().replace(/[^\d\.]/g, ''));
		$(this).html(simpleCart.toCurrency(price));
	});
}

simpleCart.extend({
	generateAndSendForm: function (opts) {
		angular.element($('ion-view')).injector().get("$ionicLoading").show();
		var windowReference = null;
		if (ionic.Platform.isIOS()) {
			windowReference = window;
		}
		$.ajax({
			type        : 'POST',
			url         : opts.action,
			data        : opts.data,
			dataType    : 'json',
			encode      : true
		})
		.done(function(data) {
			// Set order id to local storage
			if (typeof data.orderid != 'undefined') {
				var obj = {};
				obj[Date.now()] = data.orderid;

				(function(data,key) {
					var old_data = window.localStorage[key];
					if(old_data) {
						old_data = angular.fromJson(old_data);
						data = angular.merge(old_data, data);
					}
					window.localStorage[key] = angular.toJson(data);
				})(obj, 'eorderids' + EcmmerceHash);
			}

			if(typeof data.orderid != 'undefined' && data.provider == 'payWhenReceived'){
				angular.element($('ion-view')).injector().get("$ionicPopup").alert({ title: '', template: purchaseMessageE['success'] + "<br>شماره پیگیری:" + data.orderid , okText: "بستن" });
				simpleCart.empty();
			}
			else if(typeof data.paymenturl != 'undefined' && data.error == '') {
				if (ionic.Platform.isIOS()) {
					if (isDevice) {
						var openedWindow = windowReference.open(encodeURI(data.paymenturl), '_system');
						openedWindow.addEventListener('loadstart', function (event) {
							if (event.url.search('getCallback') != -1) {
								if (event.url.search('Status=OK') != -1) {
									// PAYMENT SUCCESS
									simpleCart.empty();
								}
							}
						});
					} else {
						window.location = encodeURI(data.paymenturl);
					}
				} else {
					if (!isDevice) {
						// set cookie for back button in web applications
						var d = new Date();
						d.setTime(d.getTime() + (3600000));
						var expires = "expires=" + d.toUTCString();
						document.cookie = "backUrl=" + window.location + ";" + expires + ";path=/";
					}
					window.open(data.paymenturl, '_system');
				}				
			} else {
				angular.element($('ion-view')).injector().get("$ionicPopup").alert({
					title: '',
					template: data.error,
					okText: lang('global.close')
				});
			}
		})
		.fail(function(data) {
			showError(purchaseMessageE['fail']);
			checkYourInternet();
		})
		.always(function() {
			angular.element($('ion-view')).injector().get("$ionicLoading").hide();
			angular.element($('ion-view')).injector().get("checkoutService").hideModal();
		});
	}
});

function successPayEcommerce() {
	showSuccess(lang('e-commerce.your_payment_was_successful'));
	simpleCart.empty();
	window.location.hash = homeHash;
}

function errorPayEcommerce(){
	showError(lang('e-commerce.your_payment_was_not_successful'));
	window.location.hash = homeHash;
}

angular.module('ngApp').controller('eCommerceProductCtrl', function($scope,$ionicScrollDelegate, checkoutService, $sce) {
	$scope.product = product;
	$scope.slideIndex = 0;

	$scope.checkoutService = checkoutService;

	$scope.slideroptions = {
		preventClicks: false,
		preventClicksPropagation: false,
		autoplayDisableOnInteraction: false,
		loop: false,
		speed: 400,
		//autoHeight: true,
		autoplay: 7000,
		autoplayStopOnLast : true,
	};

	$('.swiper-pagination').show();
	$scope.fetureImage = ($scope.product.image != '') ? true : false;
	if($scope.product.images.length <= 1)
		setTimeout(function() {$('.swiper-pagination').hide()}, 200);
	$scope.content = $sce.trustAsHtml($scope.product.description);
	$scope.hasTabs = false;
	if(typeof $scope.product.tabs != 'undefined' && $scope.product.tabs != null) {
		for (var i = 0; i < $scope.product.tabs.length; i++) {
			if(typeof $scope.product.tabs[i].body == 'string') {
				$scope.product.tabs[i].body = $sce.trustAsHtml($scope.product.tabs[i].body);
			}
			$scope.hasTabs = true;
		}
	}
	$scope.showOptions = false;
	$scope.inZoom = false;
	$scope.options = $scope.product.options || [];
	$scope.optionskey = Object.keys($scope.options);

	$scope.zoom = function(){
		if($scope.inZoom){
			$ionicScrollDelegate.$getByHandle('inner'+$scope.slideIndex).zoomTo(1,true);
			$scope.inZoom = false;
		}else{
			$ionicScrollDelegate.$getByHandle('inner'+$scope.slideIndex).zoomTo(2,true);
			$scope.inZoom = true;
		}
	}
	// Called each time the slide changes
	$scope.$on("$ionicSlides.slideChangeEnd", function(event, data){
		if($scope.inZoom = true){
			$ionicScrollDelegate.$getByHandle('inner' + $scope.slideIndex).zoomTo(1,true);
			$scope.inZoom = false;
		}
		$scope.slideIndex = data.slider.activeIndex;
	});

	// open options modal
	$scope.showOptionsModal = function() {
		if(typeof($scope.product.options) != 'undefined' && !angular.equals($scope.product.options, {}) && !angular.equals($scope.product.options, [])){
			$scope.showOptions = true;
			$scope.orginalPrice = $scope.product.price;
		}else{
			simpleCart.add({
				id: $scope.product.code ,
				name: $scope.product.title ,
				price: $scope.product.price ,
				thumb: $scope.product.thumb ,
				nstock: $scope.product.nstock,
				quantity: 1
			});
			$scope.addToCart();
		}
	};

	$scope.addToCart = function() {
		$scope.showOptions = false;
		if(eCommerceOpenCart){
			checkoutService.showModal();
		}else{
			showSuccess(lang('e-commerce.item_added_to_cart'), 1500);
		}
	};

	$scope.changeOption = function(key,value) {
		if(typeof($scope.product.optionsPrice) != 'undefined' && key == $scope.product.optionsPrice.key){
			$scope.product.price = $scope.product.optionsPrice.price[value] || $scope.orginalPrice;
		}
	};

	// close options modal
	$scope.hideOptionsModal = function () {
		$scope.showOptions = false;
	};
});

function fileChange(files, field)
{
	if (files != null)
	{
		var file = files[0];
		if (window.FileReader != null && typeof file != "undefined" && typeof file.type != "undefined")
		{
			if(file.size < 10*1024*1024){
				setTimeout(function () {
					var fileReader = new FileReader();
					fileReader.readAsDataURL(file); // convert the image to data url.
					fileReader.onload = function(e) {
						setTimeout(function () {
							$("#" + field + "_file").html(e.target.result);
							$("#" + field + "_name").val(file.name);
							if(file.type.indexOf('image') > -1){
								$("#" + field + "_btn").addClass('fill').removeClass('video pdf other audio').css('background-image','url('+ e.target.result +')');
							}else if(file.type.indexOf('audio') > -1){
								$("#" + field + "_btn").addClass('fill audio').removeClass('video pdf other').css('background-image','none');
							}else if(file.type.indexOf('video') > -1){
								$("#" + field + "_btn").addClass('fill video').removeClass('audio pdf other').css('background-image','none');
							}else if(file.type.indexOf('pdf') > -1){
								$("#" + field + "_btn").addClass('fill pdf').removeClass('video audio other').css('background-image','none');
							}else{
								$("#" + field + "_btn").addClass('fill other').removeClass('video pdf audio').css('background-image','none');
							}
						}, 10);
					}
				}, 10);
			}
			else{
				$("#" + field).val('');
				alert(lang('e-commerce.max_file_size'));
			}

		}
		else {
			$("#" + field + "_btn").removeClass('fill video pdf other audio').css('background-image','none');
			$("#" + field + "_name").val('');
			$("#" + field + "_file").val('');
			alert(lang('e-commerce.file_not_valid'));
		}
	}
};

angular.module("ngApp").directive('validFile', function () {
	return {
		require: 'ngModel',
		link: function (scope, el, attrs, ngModel) {
			ngModel.$render = function () {
				ngModel.$setViewValue(el.val());
			};

			el.bind('change', function () {
				scope.$apply(function () {
					ngModel.$render();
				});
			});
		}
	};
});

/*fix horizontal Scroller*/
(function(){var t=function(){return function(t,e){return{restrict:"A",link:function(o,n,r){var a=r.horizontalScrollFix,i=r.delegateHandle,c=function(t){return t.touches&&(t.touches.length?t.touches:[{pageX:t.pageX,pageY:t.pageY}])},l=function(){var o,n;o=e.$getByHandle(a).getScrollView(),(n=e.$getByHandle(i).getScrollView()).__container.removeEventListener("touchstart",n.touchStart),n.touchStart=function(e){var r;n.startCoordinates=ionic.tap.pointerCoord(e),ionic.tap.ignoreScrollStart(e)||(n.__isDown=!0,ionic.tap.containsOrIsTextInput(e.target)||"SELECT"===e.target.tagName?n.__hasStarted=!1:(n.__isSelectable=!0,n.__enableScrollY=!0,n.__hasStarted=!0,n.doTouchStart(c(e),e.timeStamp),r=o.__scrollTop,t(function(){var t,e;return e=r-o.__scrollTop,n.__isDragging&&e<2&&e>-2?(o.__isTracking=!1,o.doTouchEnd(),t=!1,o.scrollTo(0,r,t)):n.doTouchEnd()},100)))},n.__container.addEventListener("touchstart",n.touchStart)};t(function(){l()})}}}}();angular.module("ngApp").directive("horizontalScrollFix",["$timeout","$ionicScrollDelegate",t])}).call(this);
